import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import React, { useState, useEffect } from 'react';
import PropTypes from 'prop-types';
import MoleculeField from '@s-ui/react-molecule-field';
import AtomTextarea, { AtomTextareaSizes as SIZES, AtomTextareaStates } from '@s-ui/react-atom-textarea';

var hasErrors = function hasErrors(_ref) {
  var successText = _ref.successText,
      errorText = _ref.errorText;
  if (errorText) return true;
  if (successText) return false;
};

var getState = function getState(_ref2) {
  var successText = _ref2.successText,
      errorState = _ref2.errorState,
      alertText = _ref2.alertText;
  if (successText) return AtomTextareaStates.SUCCESS;
  if (errorState) return AtomTextareaStates.ERROR;
  if (alertText) return AtomTextareaStates.ALERT;
};

var MoleculeTextareaField = function MoleculeTextareaField(_ref3) {
  var id = _ref3.id,
      label = _ref3.label,
      maxChars = _ref3.maxChars,
      _ref3$textCharacters = _ref3.textCharacters,
      textCharacters = _ref3$textCharacters === void 0 ? 'characters' : _ref3$textCharacters,
      successText = _ref3.successText,
      errorText = _ref3.errorText,
      alertText = _ref3.alertText,
      _ref3$autoHideHelpTex = _ref3.autoHideHelpText,
      autoHideHelpText = _ref3$autoHideHelpTex === void 0 ? false : _ref3$autoHideHelpTex,
      helpText = _ref3.helpText,
      _ref3$value = _ref3.value,
      value = _ref3$value === void 0 ? '' : _ref3$value,
      _ref3$onChange = _ref3.onChange,
      onChange = _ref3$onChange === void 0 ? function () {} : _ref3$onChange,
      props = _objectWithoutPropertiesLoose(_ref3, ["id", "label", "maxChars", "textCharacters", "successText", "errorText", "alertText", "autoHideHelpText", "helpText", "value", "onChange"]);

  var errorState = hasErrors({
    successText: successText,
    errorText: errorText
  });
  var textAreaState = getState({
    successText: successText,
    errorState: errorState,
    alertText: alertText
  });

  var _useState = useState(value),
      internalValue = _useState[0],
      setInternalValue = _useState[1];

  useEffect(function () {
    setInternalValue(value);
  }, [value]);

  var computeHelpText = function computeHelpText() {
    var numCharacters = internalValue.length;
    var dynamicText = numCharacters + "/" + maxChars + " " + textCharacters;
    return helpText ? helpText + " - " + dynamicText : dynamicText;
  };

  var onChangeHandler = function onChangeHandler(ev) {
    ev.persist();
    var value = ev.target.value;

    if (value.length <= maxChars) {
      setInternalValue(value);
      onChange(ev, {
        value: value
      });
    }
  };

  var helpTextComputed = computeHelpText();
  return /*#__PURE__*/React.createElement(MoleculeField, {
    name: id,
    label: label,
    textCharacters: textCharacters,
    successText: successText,
    errorText: errorText,
    alertText: alertText,
    helpText: helpTextComputed,
    autoHideHelpText: autoHideHelpText,
    maxChars: maxChars,
    onChange: onChangeHandler
  }, /*#__PURE__*/React.createElement(AtomTextarea, Object.assign({
    id: id,
    errorState: errorState,
    state: textAreaState,
    value: internalValue
  }, props)));
};

MoleculeTextareaField.displayName = 'MoleculeTextareaField';
MoleculeTextareaField.defaultProps = {
  maxChars: 4000
};
export default MoleculeTextareaField;